##  Organizations Fact Sheet Subtypes
Organizations are intended to address who is using certain applications. In SAP LeanIX, you can use the following 5 fact sheet subtypes for the five major dimensions that SAP LeanIX customers typically capture:
  * Business Unit: Business Units are distinct divisions within a larger organization.
Example: Retail
  * Customer: Customers represent customer groups/segments with similar needs.
Example: Buyer Persona
  * Region: Regions represent geographical divisions within a larger organization and/or business unit.
Example: Europe, Europe / France
  * Legal Entity: Legal Entities are organizations recognized by law as distinct entities.
Example: SAP LeanIX SARL
  * Team: Teams are groups of users/owners that are typically part of specific business units / countries.
Example: Team Igniteus


**Note**
For a step-by-step guide to create the fact sheet subtype, see [Add Fact Sheet Subtypes](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4?locale=en-US&state=PRODUCTION&version=CLOUD#loio27595ce97a4410149c60a90e0f529a04__add_fact_sheet_subtypes_to_several_fact_sheet_types).
